==> bootstrap-2.6.1.tgz: package/ListStars/ListStars.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const ListStars = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M5 11.5a.5.5 0 01.5-.5h9a.5.5 0 010 1h-9a.5.5 0 01-.5-.5zm0-4a.5.5 0 01.5-.5h9a.5.5 0 010 1h-9a.5.5 0 01-.5-.5zm0-4a.5.5 0 01.5-.5h9a.5.5 0 010 1h-9a.5.5 0 01-.5-.5z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M2.242 2.194a.27.27 0 01.516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 00-.094.3l.173.569c.078.256-.213.462-.423.3l-.417-.324a.267.267 0 00-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 00-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 00.259-.194l.162-.53zm0 4a.27.27 0 01.516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 00-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 00-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 00-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 00.259-.194l.162-.53zm0 4a.27.27 0 01.516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 00-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 00-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 00-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 00.259-.194l.162-.53z"
  }));
});
ListStars.displayName = 'ListStars';
export const ListStarsDimensions = {
  height: 16,
  width: 16
};

==> bootstrap-2.7.1.tgz: package/ListStars/ListStars.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var ListStars = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M5 11.5a.5.5 0 01.5-.5h9a.5.5 0 010 1h-9a.5.5 0 01-.5-.5zm0-4a.5.5 0 01.5-.5h9a.5.5 0 010 1h-9a.5.5 0 01-.5-.5zm0-4a.5.5 0 01.5-.5h9a.5.5 0 010 1h-9a.5.5 0 01-.5-.5z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M2.242 2.194a.27.27 0 01.516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 00-.094.3l.173.569c.078.256-.213.462-.423.3l-.417-.324a.267.267 0 00-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 00-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 00.259-.194l.162-.53zm0 4a.27.27 0 01.516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 00-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 00-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 00-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 00.259-.194l.162-.53zm0 4a.27.27 0 01.516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 00-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 00-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 00-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 00.259-.194l.162-.53z"
  }));
});
ListStars.displayName = 'ListStars';
export var ListStarsDimensions = {
  height: 16,
  width: 16
};
